package il.ac.tau.cs.sw1.address.book;

import java.io.Serializable;

/**
 * Represents a person's contact information
 */
public class Contact implements Serializable {
	// for serialization
	private static final long serialVersionUID = 4225648967353343880L;

	private final String name; // mandatory
	private String email, phone; // optional
	private Address address; // optional

	/**
	 * Creates a new contact object for the specified person
	 * 
	 * @param name
	 *            - the name of the person (e.g. "Smith, John")
	 */
	public Contact(String name) {
		this.name = name;
	}

	/**
	 * Get the name
	 * 
	 * @return the name
	 */
	public String getName() {
		return name;
	}

	/**
	 * Get the email
	 * 
	 * @return the email
	 */
	public String getEmail() {
		return email;
	}

	/**
	 * Set the email
	 * 
	 * @param email
	 *            the email to set
	 */
	public void setEmail(String email) {
		this.email = email;
	}

	/**
	 * Get the phone
	 * 
	 * @return the phone
	 */
	public String getPhone() {
		return phone;
	}

	/**
	 * Set the phone
	 * 
	 * @param phone
	 *            the phone to set
	 */
	public void setPhone(String phone) {
		this.phone = phone;
	}

	/**
	 * Get the address
	 * 
	 * @return the address
	 */
	public Address getAddress() {
		return address;
	}

	/**
	 * Set the address
	 * 
	 * @param address
	 *            the address to set
	 */
	public void setAddress(Address address) {
		this.address = address;
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append(String.format("Name:\t%s\n", name));
		if (email != null && !email.isEmpty()) {
			sb.append(String.format("Email:\t%s\n", email));
		}
		if (phone != null && !phone.isEmpty()) {
			sb.append(String.format("Tel:\t%s\n", phone));
		}
		if (address != null && !address.isEmpty()) {
			sb.append(String.format("Address:\t%s\n", address.toString()));
		}
		return sb.toString();
	}
}
